package com.tzld.crawler.etl.mq;

import com.aliyun.openservices.ons.api.PropertyKeyConst;
import com.aliyun.openservices.ons.api.batch.BatchMessageListener;
import com.aliyun.openservices.ons.api.bean.BatchConsumerBean;
import com.aliyun.openservices.ons.api.bean.Subscription;
import com.tzld.crawler.etl.config.MqConfig;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;

import java.util.HashMap;
import java.util.Map;
import java.util.Properties;

/**
 * @author supeng
 */
@Configuration
public class BatchConsumerClient {

    @Autowired
    private MqConfig mqConfig;

    @Autowired
    private EtlBatchMessageListener etlBatchMessageListener;

    @Bean(initMethod = "start", destroyMethod = "shutdown")
    public BatchConsumerBean buildBatchConsumer() {
        BatchConsumerBean batchConsumerBean = new BatchConsumerBean();
        //配置文件
        Properties properties = mqConfig.getMqPropertie();
        properties.setProperty(PropertyKeyConst.GROUP_ID, mqConfig.getGroupId());
        //将消费者线程数固定为1000个 20为默认值  范围[1,1000]
        properties.setProperty(PropertyKeyConst.ConsumeThreadNums, "100");
        //批量消费的最大消息数量
        properties.setProperty(PropertyKeyConst.ConsumeMessageBatchMaxSize, "10");
        batchConsumerBean.setProperties(properties);
        //订阅关系
        Map<Subscription, BatchMessageListener> subscriptionTable = new HashMap<>();
        Subscription subscription = new Subscription();
        subscription.setTopic(mqConfig.getTopic());
        subscription.setExpression(mqConfig.getTag());
        subscriptionTable.put(subscription, etlBatchMessageListener);
        //订阅多个topic如上面设置
//        Subscription subscription1 = new Subscription();
//        subscription1.setTopic(mqConfig.getTopic());
//        subscription1.setExpression(mqConfig.getTag());
//        subscriptionTable.put(subscription1, etlBatchMessageListener1);

        batchConsumerBean.setSubscriptionTable(subscriptionTable);
        return batchConsumerBean;
    }

}
