package com.tzld.crawler.etl.mq;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.aliyun.openservices.ons.api.Action;
import com.aliyun.openservices.ons.api.ConsumeContext;
import com.aliyun.openservices.ons.api.Message;
import com.tzld.crawler.etl.model.dto.EtlMessageDTO;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Component;

import java.nio.charset.StandardCharsets;
import java.util.List;

/**
 * 新增消息 批量消费
 *
 * @author supeng
 */
@Component
public class EtlBatchMessageListener implements com.aliyun.openservices.ons.api.batch.BatchMessageListener {

    private static final Logger LOGGER = LoggerFactory.getLogger(EtlBatchMessageListener.class);
    @Override
    public Action consume(final List<Message> messages, final ConsumeContext context) {
        LOGGER.info("Receive message size = {}", messages.size());
        try {
            for (Message message : messages) {
                try {
                    String body = new String(message.getBody(), StandardCharsets.UTF_8);
                    LOGGER.info("message body = {}", body);
                    EtlMessageDTO etlMessageDTO = JSONObject.parseObject(body, EtlMessageDTO.class);
                    //todo

                } catch (Exception e) {
                    LOGGER.info("loop message error {}", e, JSON.toJSONString(message));
                }
            }
            //消费成功
            return Action.CommitMessage;
        } catch (Exception e) {
            //消费失败
            return Action.ReconsumeLater;
        }
    }
}
